@@ -12,6 +12,7 @@ Configuration parameters:
         (default 60)
     charging_character: a character to represent charging battery
         especially useful when using icon fonts (e.g. FontAwesome)
+        set to 'None' if you want to hide the charging state of your battery
         (default "⚡")
     format: string that formats the output. See placeholders below.
         (default "{icon}")
@@ -338,7 +339,9 @@ class Py3status:
             remaining_energy = r.get(
                 "POWER_SUPPLY_ENERGY_NOW", r.get("POWER_SUPPLY_CHARGE_NOW")
             )
-            current_now = r.get("POWER_SUPPLY_CURRENT_NOW", 0)
+            current_now = r.get(
+                "POWER_SUPPLY_CURRENT_NOW", r.get("POWER_SUPPLY_POWER_NOW", 0)
+            )
             voltage_now = r.get("POWER_SUPPLY_VOLTAGE_NOW", 0)
 
             # missing values may indicate this is not a battery and should be skipped
@@ -365,7 +368,7 @@ class Py3status:
                     time_in_secs = remaining_energy / present_rate * 3600
                 battery["time_remaining"] = self._seconds_to_hms(time_in_secs)
 
-            battery["power"] = current_now * voltage_now / 10 ** 12
+            battery["power"] = current_now * voltage_now / 10**12
 
             battery_list.append(battery)
         return battery_list
@@ -475,7 +478,7 @@ class Py3status:
             self.status = self.format_status_discharging
 
     def _update_icon(self):
-        if self.charging:
+        if self.charging and self.charging_character is not None:
             self.icon = self.charging_character
         else:
             self.icon = self.blocks[
